# Dhivatar
Generates avatars from dhivehi names or strings


## Credits
* [PhoenixAtom](https://github.com/phoenixatom) - Author
* [Athphane](https://github.com/athphane) - Idea
* [Avatar-Generator](https://github.com/maethor/avatar-generator)